@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.12-4996.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_YY_WINPREFSYACC_H_INCLUDED
 # define YY_YY_WINPREFSYACC_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,42 +40,41 @@
 extern int yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     NEWLINE = 258,
-     MENU = 259,
-     LB = 260,
-     RB = 261,
-     ICONDIRECTORY = 262,
-     DEFAULTICON = 263,
-     ICONS = 264,
-     STYLES = 265,
-     TOPMOST = 266,
-     MAXIMIZE = 267,
-     MINIMIZE = 268,
-     BOTTOM = 269,
-     NOTITLE = 270,
-     OUTLINE = 271,
-     NOFRAME = 272,
-     DEFAULTSYSMENU = 273,
-     SYSMENU = 274,
-     ROOTMENU = 275,
-     SEPARATOR = 276,
-     ATSTART = 277,
-     ATEND = 278,
-     EXEC = 279,
-     ALWAYSONTOP = 280,
-     DEBUGOUTPUT = 281,
-     RELOAD = 282,
-     TRAYICON = 283,
-     FORCEEXIT = 284,
-     SILENTEXIT = 285,
-     STRING = 286
-   };
+  enum yytokentype
+  {
+    NEWLINE = 258,
+    MENU = 259,
+    LB = 260,
+    RB = 261,
+    ICONDIRECTORY = 262,
+    DEFAULTICON = 263,
+    ICONS = 264,
+    STYLES = 265,
+    TOPMOST = 266,
+    MAXIMIZE = 267,
+    MINIMIZE = 268,
+    BOTTOM = 269,
+    NOTITLE = 270,
+    OUTLINE = 271,
+    NOFRAME = 272,
+    DEFAULTSYSMENU = 273,
+    SYSMENU = 274,
+    ROOTMENU = 275,
+    SEPARATOR = 276,
+    ATSTART = 277,
+    ATEND = 278,
+    EXEC = 279,
+    ALWAYSONTOP = 280,
+    DEBUGOUTPUT = 281,
+    RELOAD = 282,
+    TRAYICON = 283,
+    FORCEEXIT = 284,
+    SILENTEXIT = 285,
+    STRING = 286
+  };
 #endif
 /* Tokens.  */
 #define NEWLINE 258
@@ -108,41 +107,26 @@ extern int yydebug;
 #define SILENTEXIT 285
 #define STRING 286
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-/* Line 2053 of yacc.c  */
-#line 89 "winprefsyacc.y"
+#line 89 "../../../hw/xwin/winprefsyacc.y" /* yacc.c:1909  */
 
   char *sVal;
   unsigned long uVal;
   int iVal;
 
-
-/* Line 2053 of yacc.c  */
-#line 126 "winprefsyacc.h"
-} YYSTYPE;
+#line 122 "winprefsyacc.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_YY_WINPREFSYACC_H_INCLUDED  */
